#!/usr/bin/env PYTHONHASHSEED=1234 python3

# Copyright 2014-2019 Brett Slatkin, Pearson Education Inc.
#
# Udostępniono na licencji Apache w wersji 2.0 ("Licencja").
# Tego pliku można używać jedynie zgodnie z warunkami Licencji.
# Treść Licencji znajdziesz na stronie:
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# O ile obowiązujące prawo nie stanowi inaczej lub czegoś innego nie
# uzgodniono w formie pisemnej, oprogramowanie objęte Licencją jest
# dostarczane w stanie, w jakim jest (wersja "AS IS"), BEZ JAKIEJKOLWIEK
# GWARANCJI, ani wyrażonej otwarcie, ani domyślnej. Dokładne zasady
# i warunki Licencji znajdziesz w jej treści.

# Przygotowania mające na celu odtworzenie środowiska użytego w książce.
import random
random.seed(1234)

import logging
from pprint import pprint
from sys import stdout as STDOUT

# Wygenerowanie wszystkich danych wyjściowych w katalogu tymczasowym.
import atexit
import gc
import io
import os
import tempfile

TEST_DIR = tempfile.TemporaryDirectory()
atexit.register(TEST_DIR.cleanup)

# Prawidłowe zakończenie procesów w systemie Windows.
OLD_CWD = os.getcwd()
atexit.register(lambda: os.chdir(OLD_CWD))
os.chdir(TEST_DIR.name)

def close_open_files():
    everything = gc.get_objects()
    for obj in everything:
        if isinstance(obj, io.IOBase):
            obj.close()

atexit.register(close_open_files)


# Przykład 1.
snack_calories = {
	'chipsy': 140,
	'popcorn': 80,
	'orzeszki': 190,
}
items = tuple(snack_calories.items())
print(items)


# Przykład 2.
item = ('Masło orzechowe', 'dżem')
first = item[0]
second = item[1]
print(first, 'i', second)


# Przykład 3.
try:
    pair = ('Czekolada', 'Masło orzechowe')
    pair[0] = 'Miód'
except:
    logging.exception('Wystąpił błąd w kodzie wywołującym.')
else:
    assert False


# Przykład 4.
item = ('Masło orzechowe', 'dżem')
first, second = item  # Rozpakowanie.
print(first, 'i', second)


# Przykład 5.
favorite_snacks = {
	'słona': ('precle', 100),
	'słodka': ('ciasteczka', 180),
	'warzywna': ('marchewki', 20),
}

((type1, (name1, cals1)),
 (type2, (name2, cals2)),
 (type3, (name3, cals3))) = favorite_snacks.items()

print(f'Ulubiona przekąska {type1} to {name1} o {cals1} kaloriach')
print(f'Ulubiona przekąska {type2} to {name2} o {cals2} kaloriach')
print(f'Ulubiona przekąska {type3} to {name3} o {cals3} kaloriach')


# Przykład 6.
def bubble_sort(a):
	for _ in range(len(a)):
		for i in range(1, len(a)):
			if a[i] < a[i-1]:
				temp = a[i]
				a[i] = a[i-1]
				a[i-1] = temp

names = ['precle', 'marchewki', 'rukola', 'bekon']
bubble_sort(names)
print(names)


# Przykład 7.
def bubble_sort(a):
	for _ in range(len(a)):
		for i in range(1, len(a)):
			if a[i] < a[i-1]:
				a[i-1], a[i] = a[i], a[i-1]  # Zamiana wartości miejscami.

names = ['precle', 'marchewki', 'rukola', 'bekon']
bubble_sort(names)
print(names)


# Przykład 8.
snacks = [('bekon', 350), ('pączek', 240), ('babeczka', 190)]
for i in range(len(snacks)):
	item = snacks[i]
	name = item[0]
	calories = item[1]
	print(f'#{i+1}: {name} ma {calories} kalorii')


# Przykład 9.
for rank, (name, calories) in enumerate(snacks, 1):
	print(f'#{rank}: {name} ma {calories} kalorii')
